@@ -41,7 +41,7 @@ import org.apache.commons.validator.util.ValidatorUtils;
  *
  * <strong>Note</strong>: The validation method is assumed to be thread safe.
  *
- * @version $Revision: 1227719 $ $Date: 2012-01-05 18:45:51 +0100 (Thu, 05 Jan 2012) $
+ * @version $Revision: 1649191 $
  */
 public class ValidatorAction implements Serializable {
 
@@ -149,13 +149,13 @@ public class ValidatorAction implements Serializable {
      * setDepends() (which clears the List) won't interfere with a call to
      * isDependency().
      */
-    private List dependencyList = Collections.synchronizedList(new ArrayList());
+    private final List dependencyList = Collections.synchronizedList(new ArrayList());
 
     /**
      * An internal List representation of all the validation method's
      * parameters defined in the methodParams String.
      */
-    private List methodParameterList = new ArrayList();
+    private final List methodParameterList = new ArrayList();
 
     /**
      * Gets the name of the validator action.
@@ -752,9 +752,8 @@ public class ValidatorAction implements Serializable {
         if (result instanceof Boolean) {
             Boolean valid = (Boolean) result;
             return valid.booleanValue();
-        } else {
-            return (result != null);
         }
+        return result != null;
     }
 
     /**
