@@ -23,12 +23,12 @@ import org.apache.commons.validator.ResultPair;
 /**
  * Performs Validation Test for url validations.
  *
- * @version $Revision: 1128446 $ $Date: 2011-05-27 22:29:27 +0200 (Fri, 27 May 2011) $
+ * @version $Revision: 1649975 $
  */
 public class UrlValidatorTest extends TestCase {
 
-   private boolean printStatus = false;
-   private boolean printIndex = false;//print index that indicates current scheme,host,port,path, query test were using.
+   private final boolean printStatus = false;
+   private final boolean printIndex = false;//print index that indicates current scheme,host,port,path, query test were using.
 
    public UrlValidatorTest(String testName) {
       super(testName);
@@ -55,7 +55,6 @@ public class UrlValidatorTest extends TestCase {
       if (printStatus) {
          System.out.print("\n testIsValidScheme() ");
       }
-      String[] schemes = {"http", "gopher"};
       //UrlValidator urlVal = new UrlValidator(schemes,false,false,false);
       UrlValidator urlVal = new UrlValidator(schemes, 0);
       for (int sIndex = 0; sIndex < testScheme.length; sIndex++) {
@@ -128,7 +127,7 @@ public class UrlValidatorTest extends TestCase {
    public void testValidator202() {
        String[] schemes = {"http","https"};
        UrlValidator urlValidator = new UrlValidator(schemes, UrlValidator.NO_FRAGMENTS);
-       assertTrue(urlValidator.isValid("http://www.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.org"));
+       assertTrue(urlValidator.isValid("http://l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.org"));
    }
 
    public void testValidator204() {
@@ -143,6 +142,21 @@ public class UrlValidatorTest extends TestCase {
                validator.isValid("http://somewhere.com/pathxyz/file(1).html"));
    }
 
+   public void testValidator235() {
+       String version = System.getProperty("java.version");
+       if (version.compareTo("1.6") < 0) {
+           System.out.println("Cannot run Unicode IDN tests");
+           return; // Cannot run the test
+       }
+       UrlValidator validator = new UrlValidator();
+       assertTrue("xn--d1abbgf6aiiy.xn--p1ai should validate", validator.isValid("http://xn--d1abbgf6aiiy.xn--p1ai"));
+       assertTrue("президент.рф should validate", validator.isValid("http://президент.рф"));
+       assertTrue("www.b\u00fccher.ch should validate", validator.isValid("http://www.b\u00fccher.ch"));
+       assertFalse("www.\uFFFD.ch FFFD should fail", validator.isValid("http://www.\uFFFD.ch"));
+       assertTrue("www.b\u00fccher.ch should validate", validator.isValid("ftp://www.b\u00fccher.ch"));
+       assertFalse("www.\uFFFD.ch FFFD should fail", validator.isValid("ftp://www.\uFFFD.ch"));
+   }
+
     public void testValidator248() {
         RegexValidator regex = new RegexValidator(new String[] {"localhost", ".*\\.my-testing"});
         UrlValidator validator = new UrlValidator(regex, 0);
@@ -261,7 +275,33 @@ public class UrlValidatorTest extends TestCase {
     }
 
     
-   static boolean incrementTestPartsIndex(int[] testPartsIndex, Object[] testParts) {
+    public void testValidator309() {
+        UrlValidator urlValidator = new UrlValidator();
+        assertTrue(urlValidator.isValid("http://sample.ondemand.com/"));
+        assertTrue(urlValidator.isValid("hTtP://sample.ondemand.CoM/"));
+        assertTrue(urlValidator.isValid("httpS://SAMPLE.ONEMAND.COM/"));
+        urlValidator = new UrlValidator(new String[] {"HTTP","HTTPS"});
+        assertTrue(urlValidator.isValid("http://sample.ondemand.com/"));
+        assertTrue(urlValidator.isValid("hTtP://sample.ondemand.CoM/"));
+        assertTrue(urlValidator.isValid("httpS://SAMPLE.ONEMAND.COM/"));
+    }
+
+    public void testValidator339(){
+        UrlValidator urlValidator = new UrlValidator();
+        assertTrue(urlValidator.isValid("http://www.cnn.com/WORLD/?hpt=sitenav")); // without
+        assertTrue(urlValidator.isValid("http://www.cnn.com./WORLD/?hpt=sitenav")); // with
+        assertFalse(urlValidator.isValid("http://www.cnn.com../")); // doubly dotty
+        assertFalse(urlValidator.isValid("http://www.cnn.invalid/"));
+        assertFalse(urlValidator.isValid("http://www.cnn.invalid./")); // check . does not affect invalid domains
+    }
+
+    public void testValidator342(){
+        UrlValidator urlValidator = new UrlValidator();
+        assertTrue(urlValidator.isValid("http://example.rocks/"));
+        assertTrue(urlValidator.isValid("http://example.rocks"));
+    }
+
+    static boolean incrementTestPartsIndex(int[] testPartsIndex, Object[] testParts) {
       boolean carry = true;  //add 1 to lowest order part.
       boolean maxIndex = true;
       for (int testPartsIndexIndex = testPartsIndex.length - 1; testPartsIndexIndex >= 0; --testPartsIndexIndex) {
@@ -302,6 +342,65 @@ public class UrlValidatorTest extends TestCase {
       assertTrue(true);
    }
 
+   public void testValidator290() {
+        UrlValidator validator = new UrlValidator();
+        assertTrue(validator.isValid("http://xn--h1acbxfam.idn.icann.org/"));
+//        assertTrue(validator.isValid("http://xn--e1afmkfd.xn--80akhbyknj4f"));
+        // Internationalized country code top-level domains
+        assertTrue(validator.isValid("http://test.xn--lgbbat1ad8j")); //Algeria
+        assertTrue(validator.isValid("http://test.xn--fiqs8s")); // China
+        assertTrue(validator.isValid("http://test.xn--fiqz9s")); // China
+        assertTrue(validator.isValid("http://test.xn--wgbh1c")); // Egypt
+        assertTrue(validator.isValid("http://test.xn--j6w193g")); // Hong Kong
+        assertTrue(validator.isValid("http://test.xn--h2brj9c")); // India
+        assertTrue(validator.isValid("http://test.xn--mgbbh1a71e")); // India
+        assertTrue(validator.isValid("http://test.xn--fpcrj9c3d")); // India
+        assertTrue(validator.isValid("http://test.xn--gecrj9c")); // India
+        assertTrue(validator.isValid("http://test.xn--s9brj9c")); // India
+        assertTrue(validator.isValid("http://test.xn--xkc2dl3a5ee0h")); // India
+        assertTrue(validator.isValid("http://test.xn--45brj9c")); // India
+        assertTrue(validator.isValid("http://test.xn--mgba3a4f16a")); // Iran
+        assertTrue(validator.isValid("http://test.xn--mgbayh7gpa")); // Jordan
+        assertTrue(validator.isValid("http://test.xn--mgbc0a9azcg")); // Morocco
+        assertTrue(validator.isValid("http://test.xn--ygbi2ammx")); // Palestinian Territory
+        assertTrue(validator.isValid("http://test.xn--wgbl6a")); // Qatar
+        assertTrue(validator.isValid("http://test.xn--p1ai")); // Russia
+        assertTrue(validator.isValid("http://test.xn--mgberp4a5d4ar")); //  Saudi Arabia
+        assertTrue(validator.isValid("http://test.xn--90a3ac")); // Serbia
+        assertTrue(validator.isValid("http://test.xn--yfro4i67o")); // Singapore
+        assertTrue(validator.isValid("http://test.xn--clchc0ea0b2g2a9gcd")); // Singapore
+        assertTrue(validator.isValid("http://test.xn--3e0b707e")); // South Korea
+        assertTrue(validator.isValid("http://test.xn--fzc2c9e2c")); // Sri Lanka
+        assertTrue(validator.isValid("http://test.xn--xkc2al3hye2a")); // Sri Lanka
+        assertTrue(validator.isValid("http://test.xn--ogbpf8fl")); // Syria
+        assertTrue(validator.isValid("http://test.xn--kprw13d")); // Taiwan
+        assertTrue(validator.isValid("http://test.xn--kpry57d")); // Taiwan
+        assertTrue(validator.isValid("http://test.xn--o3cw4h")); // Thailand
+        assertTrue(validator.isValid("http://test.xn--pgbs0dh")); // Tunisia
+        assertTrue(validator.isValid("http://test.xn--mgbaam7a8h")); // United Arab Emirates
+        // Proposed internationalized ccTLDs
+//        assertTrue(validator.isValid("http://test.xn--54b7fta0cc")); // Bangladesh
+//        assertTrue(validator.isValid("http://test.xn--90ae")); // Bulgaria
+//        assertTrue(validator.isValid("http://test.xn--node")); // Georgia
+//        assertTrue(validator.isValid("http://test.xn--4dbrk0ce")); // Israel
+//        assertTrue(validator.isValid("http://test.xn--mgb9awbf")); // Oman
+//        assertTrue(validator.isValid("http://test.xn--j1amh")); // Ukraine
+//        assertTrue(validator.isValid("http://test.xn--mgb2ddes")); // Yemen
+        // Test TLDs
+//        assertTrue(validator.isValid("http://test.xn--kgbechtv")); // Arabic
+//        assertTrue(validator.isValid("http://test.xn--hgbk6aj7f53bba")); // Persian
+//        assertTrue(validator.isValid("http://test.xn--0zwm56d")); // Chinese
+//        assertTrue(validator.isValid("http://test.xn--g6w251d")); // Chinese
+//        assertTrue(validator.isValid("http://test.xn--80akhbyknj4f")); // Russian
+//        assertTrue(validator.isValid("http://test.xn--11b5bs3a9aj6g")); // Hindi
+//        assertTrue(validator.isValid("http://test.xn--jxalpdlp")); // Greek
+//        assertTrue(validator.isValid("http://test.xn--9t4b11yi5a")); // Korean
+//        assertTrue(validator.isValid("http://test.xn--deba0ad")); // Yiddish
+//        assertTrue(validator.isValid("http://test.xn--zckzah")); // Japanese
+//        assertTrue(validator.isValid("http://test.xn--hlcj6aya9esc7a")); // Tamil
+    }
+
+   
    /**
     * Only used to debug the unit tests.
     * @param argv
@@ -399,9 +498,17 @@ public class UrlValidatorTest extends TestCase {
    int[] testPartsIndex = {0, 0, 0, 0, 0};
 
    //---------------- Test data for individual url parts ----------------
+   private final String[] schemes = {"http", "gopher", "g0-To+.",
+                                      "not_valid" // TODO this will need to be dropped if the ctor validates schemes
+                                    };
+
    ResultPair[] testScheme = {new ResultPair("http", true),
                             new ResultPair("ftp", false),
                             new ResultPair("httpd", false),
+                            new ResultPair("gopher", true),
+                            new ResultPair("g0-to+.", true),
+                            new ResultPair("not_valid", false), // underscore not allowed
+                            new ResultPair("HtTp", true),
                             new ResultPair("telnet", false)};
 
 
